@@ -8,6 +8,7 @@
 #'  for the dataset(s) to be downloaded (see details).
 #' @param name,org,phone,email Contact information to submit to Pew Research Center
 #'  (see details).
+#' @param reset If TRUE, the register information will be reset. The default is FALSE.
 #' @param download_dir The directory (relative to your working directory) to
 #'   which files from the Pew Research Center will be downloaded.
 #' @param msg If TRUE, outputs a message showing which data set is being downloaded.
@@ -51,79 +52,92 @@
 #'  pew_download(file_id = c(20059299, 20058139))
 #' }
 #'
+#' @importFrom rvest html_session html_form set_values submit_form
+#' @importFrom magrittr "%>%"
+#' @importFrom purrr walk
+#' 
 #' @export
+
 pew_download <- function(area = "politics",
                          file_id, 
                          name = getOption("pew_name"),
                          org = getOption("pew_org"),
                          phone = getOption("pew_phone"),
                          email = getOption("pew_email"),
+                         reset = FALSE,
                          download_dir = "pew_data",
                          msg = TRUE,
                          unzip = TRUE,
                          delete_zip = TRUE) {
-
-  # Set Firefox properties to not open a download dialog
-  fprof <- RSelenium::makeFirefoxProfile(list(
-    browser.download.dir = paste0(getwd(), "/", download_dir),
-    browser.download.folderList = 2L,
-    browser.download.manager.showWhenStarting = FALSE,
-    browser.helperApps.neverAsk.saveToDisk = "application/zip"))
   
-  # Set up server as open initial window
-  RSelenium::checkForServer()
-  RSelenium::startServer()
-  remDr <- RSelenium::remoteDriver(extraCapabilities = fprof)
-  remDr$open(silent = TRUE)
+  # Detect the login info
+  if (reset){
+    name <- org <- phone <- email <- NULL
+  }
+  
+  if (is.null(name)){
+    pew_name <- readline(prompt = "The Pew Data Center requires some user information.  Please enter your name: \n")
+    options("pew_name" = pew_name)
+    name <- getOption("pew_name")
+  }
+  
+  if (is.null(org)){
+    pew_org <- readline(prompt = "Please enter your organization to submit to Pew: \n")
+    options("pew_org" = pew_org)
+    org <- getOption("pew_org")
+  }
+  
+  if (is.null(phone)){
+    pew_phone = readline(prompt = "Please enter the phone number to submit to Pew: \n")
+    options("pew_phone" = pew_phone)
+    phone <-  getOption("pew_phone")
+  }
+  
+  if (is.null(email)){
+    pew_email <- readline(prompt = "Please enter the email to submit to Pew: \n")
+    options("pew_email" = pew_email)
+    email <- getOption("pew_email")
+  }
 
   # Get list of current download directory contents
   if (!dir.exists(download_dir)) dir.create(download_dir, recursive = TRUE)
   dd_old <- list.files(download_dir)
   
   # Loop through files
-  for (item in file_id) {  
+  file_id %>% walk(function(item) {
+    # show process
     if(msg) message("Downloading Pew file: ", item, sprintf(" (%s)", Sys.time()))
     
     # build url
-    if (area == "politics") {
-      url <- paste0("http://www.people-press.org/category/datasets/?download=", item)
-    } else if (area == "journalism") {
-      url <- paste0("http://www.journalism.org/datasets/", item)
-    } else if (area == "internet") {
-      url <- paste0("http://www.pewinternet.org/datasets/", item)
-    } else if (area == "religion") {
-      url <- paste0("http://www.pewforum.org/datasets/", item)
-    } else {
-      url <- paste0("http://www.pew", area, ".org/category/datasets/?download=", item)
-    } 
+    url <- switch(area,
+                  politics = paste0("http://www.people-press.org/category/datasets/?download=", item),
+                  journalism = paste0("http://www.journalism.org/datasets/", item),
+                  internet = paste0("http://www.pewinternet.org/datasets/", item),
+                  religion = paste0("http://www.pewforum.org/datasets/", item),
+                  # default
+                  paste0("http://www.pew", area, ".org/category/datasets/?download=", item)
+                  )
+    
+    s <- html_session(url)
+    form <- html_form(s)[[1]] %>% 
+      set_values(Name = name,
+                 Organization= org,
+                 Phone = phone,
+                 Email = email) 
 
-    # navigate to download page and fill in required contact information
-    remDr$navigate(url)
+    suppressMessages(output <- submit_form(s, form))
+    file_name <- strsplit(output$response$url, "[/]") %>% 
+      unlist() 
+    file_name <- file_name[length(file_name)]  # extract the zip file name 
+    file_dir <- paste0(file.path(download_dir, file_name))
+    writeBin(httr::content(output$response, "raw"), file_dir)
     
-    remDr$findElement(using = "name", "Name")$sendKeysToElement(list(name))
-    remDr$findElement(using = "name", "Organization")$sendKeysToElement(list(org))
-    remDr$findElement(using = "name", "Phone")$sendKeysToElement(list(phone))
-    remDr$findElement(using = "name", "Email")$sendKeysToElement(list(email))
-    
-    remDr$findElement(using = "id", "Agreement")$clickElement()
-    remDr$findElement(using = "id", "submit")$clickElement()
-    
-    # Switch back to first window
-    remDr$switchToWindow(remDr$getWindowHandles()[[1]])
-  }
+    if (unzip == TRUE) unzip(file_dir, exdir = paste0(download_dir, "/", gsub(".zip", "", file_name)))
+
+    if (delete_zip == TRUE) invisible(file.remove(file_dir))
   
-  # Confirm that downloads are completed, then close driver
-  dd_new <- list.files(download_dir)[!list.files(download_dir) %in% dd_old]
-  while (any(grepl("\\.zip\\.part", dd_new))) {
-    Sys.sleep(1)
-    dd_new <- list.files(download_dir)[!list.files(download_dir) %in% dd_old]
-  }
-  remDr$close()
-  
-  if (unzip == TRUE) {
-    lapply(dd_new, function(x) unzip(paste0(download_dir, "/", x), exdir = paste0(download_dir, "/", gsub(".zip", "", x))))
-  }
-  if (delete_zip == TRUE) {
-    invisible(file.remove(paste0(download_dir, "/", dd_new)))
-  }
+  })
 }
+  
+  
+  
\ No newline at end of file
